@@ -112,11 +112,11 @@ module Rabbit
       init_menu
       attach_key(@window)
       attach_menu(@window)
-      event_mask = Gdk::Event::BUTTON_PRESS_MASK
-      event_mask |= Gdk::Event::BUTTON_RELEASE_MASK
-      event_mask |= Gdk::Event::BUTTON1_MOTION_MASK
-      event_mask |= Gdk::Event::BUTTON2_MOTION_MASK
-      event_mask |= Gdk::Event::BUTTON3_MOTION_MASK
+      event_mask = Gdk::EventMask::BUTTON_PRESS_MASK
+      event_mask |= Gdk::EventMask::BUTTON_RELEASE_MASK
+      event_mask |= Gdk::EventMask::BUTTON1_MOTION_MASK
+      event_mask |= Gdk::EventMask::BUTTON2_MOTION_MASK
+      event_mask |= Gdk::EventMask::BUTTON3_MOTION_MASK
       @window.add_events(event_mask)
       set_button_event(@window)
       set_scroll_event(@window)
@@ -125,26 +125,26 @@ module Rabbit
 
     def init_widgets(width, height)
       init_timer_label(width * (1.0 / 3.0), height * (1.0 / 3.0))
-      @outer_box = Gtk::VBox.new
+      @outer_box = Gtk::Box.new(:vertical)
 
-      current_box = Gtk::HBox.new
+      current_box = Gtk::Box.new(:horizontal)
       @current_canvas.attach_to(nil, @window, current_box) do |container, widget|
         widget.set_size_request(width * (2.0 / 3.0), height * (2.0 / 3.0))
-        container.pack_start(widget, true, false)
+        container.pack_start(widget, :expand => true, :fill => false)
       end
-      @outer_box.pack_start(current_box, true, false)
+      @outer_box.pack_start(current_box, :expand => true, :fill => false)
 
-      bottom_box = Gtk::HBox.new
+      bottom_box = Gtk::Box.new(:horizontal)
       @previous_canvas.attach_to(nil, @window, bottom_box) do |container, widget|
         widget.set_size_request(width * (1.0 / 3.0), height * (1.0 / 3.0))
-        container.pack_start(widget, false, false)
+        container.pack_start(widget, :expand => false, :fill => false)
       end
-      bottom_box.pack_start(@timer_label, true, false)
+      bottom_box.pack_start(@timer_label, :expand => true, :fill => false)
       @next_canvas.attach_to(nil, @window, bottom_box) do |container, widget|
         widget.set_size_request(width * (1.0 / 3.0), height * (1.0 / 3.0))
-        container.pack_end(widget, false, false)
+        container.pack_end(widget, :expand => false, :fill => false)
       end
-      @outer_box.pack_end(bottom_box, false, false)
+      @outer_box.pack_end(bottom_box, :expand => false, :fill => false)
 
       @outer_box.show
     end
@@ -152,33 +152,33 @@ module Rabbit
     def init_widgets_on_note_mode(width, height)
       init_timer_label(width * (1.0 / 5.0), height * (2.0 / 5.0))
       init_note_area
-      @outer_box = Gtk::VBox.new
+      @outer_box = Gtk::Box.new(:vertical)
 
-      current_box = Gtk::HBox.new
-      current_box.pack_start(@timer_label, false, false)
+      current_box = Gtk::Box.new(:horizontal)
+      current_box.pack_start(@timer_label, :expand => false, :fill => false)
       @previous_canvas.attach_to(nil, @window, current_box) do |container, widget|
         widget.set_size_request(width * (1.0 / 5.0), height * (2.0 / 5.0))
-        container.pack_start(widget, true, true, 10)
+        container.pack_start(widget, :expand => true, :fill => true, :padding => 10)
       end
       @current_canvas.attach_to(nil, @window, current_box) do |container, widget|
         widget.set_size_request(width * (2.0 / 5.0), height * (2.0 / 5.0))
-        container.pack_start(widget, true, true)
+        container.pack_start(widget, :expand => true, :fill => true)
       end
       @next_canvas.attach_to(nil, @window, current_box) do |container, widget|
         widget.set_size_request(width * (1.0 / 5.0), height * (2.0 / 5.0))
-        container.pack_end(widget, true, true, 10)
+        container.pack_end(widget, :expand => true, :fill => true, :padding => 10)
       end
-      @outer_box.pack_start(current_box, false, false)
+      @outer_box.pack_start(current_box, :expand => false, :fill => false)
 
-      bottom_box = Gtk::HBox.new
-      bottom_box.pack_start(@note_area, true, true, 20)
-      @outer_box.pack_start(bottom_box, true, true, 20)
+      bottom_box = Gtk::Box.new(:horizontal)
+      bottom_box.pack_start(@note_area, :expand => true, :fill => true, :padding => 20)
+      @outer_box.pack_start(bottom_box, :expand => true, :fill => true, :padding => 20)
 
       @outer_box.show
     end
 
     def init_canvas_widgets
-      @canvas_widgets = Gtk::HBox.new
+      @canvas_widgets = Gtk::Box.new(:horizontal)
       @current_canvas.attach_to(nil, @window, @canvas_widgets)
       @next_canvas.attach_to(nil, @window, @canvas_widgets)
     end
@@ -191,9 +191,17 @@ module Rabbit
 
     def init_note_area
       @note_area = Gtk::DrawingArea.new
-      @note_area.signal_connect("expose-event") do |area, event|
-        draw_text_as_large_as_possible(area, note_text)
-        Gdk::Event::PROPAGATE
+      if @note_area.class.signals.include?("expose-event")
+        @note_area.signal_connect("expose-event") do |area, event|
+          context = area.window.create_cairo_context
+          draw_text_as_large_as_possible(area, context, note_text)
+          Gdk::Event::PROPAGATE
+        end
+      else
+        @note_area.signal_connect("draw") do |area, context|
+          draw_text_as_large_as_possible(area, context, note_text)
+          Gdk::Event::PROPAGATE
+        end
       end
     end
 
@@ -209,12 +217,11 @@ module Rabbit
       note.gsub(/\\n/, "\n")
     end
 
-    def draw_text_as_large_as_possible(area, markupped_text)
+    def draw_text_as_large_as_possible(area, context, markupped_text)
       return if markupped_text.nil?
 
       area_width, area_height = area.window.size
 
-      context = area.window.create_cairo_context
       layout = context.create_pango_layout
       layout.context.resolution = @canvas.font_resolution
       attributes, text = Pango.parse_markup(markupped_text)
