@@ -1,9 +1,11 @@
 require "English"
 
+require "rabbit/gettext"
 require "rabbit/parser/pause-support"
 require "rabbit/parser/ext/blockdiag"
 require "rabbit/parser/ext/coderay"
 require "rabbit/parser/ext/escape"
+require "rabbit/parser/ext/inline"
 require "rabbit/parser/ext/image"
 require "rabbit/parser/ext/tex"
 
@@ -11,6 +13,7 @@ module Rabbit
   module Parser
     class Markdown
       class Converter
+        include GetText
         include Element
         include PauseSupport
 
@@ -142,15 +145,18 @@ module Rabbit
         end
 
         def convert_p(element)
-          if element.children.collect {|child| child.type} == [:img]
+          child_types = element.children.collect {|child| child.type}
+          if child_types == [:img]
             convert_container(element)[0]
           else
-            if element.children.any? {|child| child.type == :img}
+            if child_types.include?(:img)
               raise ParseError,
                       _("multiple ![alt]{image} in a paragraph isn't supported.")
-            else
-              create_paragraph(convert_container(element))
             end
+            if element.options[:transparent] and child_types == [:text]
+              element.children.first.value.chomp!
+            end
+            create_paragraph(convert_container(element))
           end
         end
 
@@ -361,6 +367,11 @@ module Rabbit
         def convert_wait(element)
           WaitTag.new
         end
+
+        def convert_note(element)
+          # TODO: Should we validate element.options[:category] == "span"?
+          Ext::Inline.note(convert_container(element))
+        end
       end
     end
   end
