@@ -1,15 +1,32 @@
-require 'rabbit/element'
-require 'rabbit/parser/pause-support'
-require 'rabbit/parser/ext/escape'
-require 'rabbit/parser/ext/inline'
-require 'rabbit/parser/ext/image'
-require 'rabbit/parser/ext/enscript'
-require 'rabbit/parser/ext/tex'
-require 'rabbit/parser/ext/aafigure'
-require 'rabbit/parser/ext/blockdiag'
-require 'rabbit/parser/ext/coderay'
-require 'rabbit/parser/ext/emacs'
-require 'rabbit/parser/ext/entity'
+# Copyright (C) 2007-2015  Kouhei Sutou <kou@cozmixng.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+require "rabbit/gettext"
+require "rabbit/element"
+require "rabbit/parser/pause-support"
+require "rabbit/parser/ext/escape"
+require "rabbit/parser/ext/inline"
+require "rabbit/parser/ext/image"
+require "rabbit/parser/ext/enscript"
+require "rabbit/parser/ext/tex"
+require "rabbit/parser/ext/aafigure"
+require "rabbit/parser/ext/blockdiag"
+require "rabbit/parser/ext/coderay"
+require "rabbit/parser/ext/emacs"
+require "rabbit/parser/ext/entity"
 
 module Rabbit
   module Parser
@@ -69,7 +86,7 @@ module Rabbit
               @parent = slide
             else
               @title_slide = false
-              slide = Slide.new(HeadLine.new(title))
+              slide = Element::Slide.new(HeadLine.new(title))
               body = Body.new
               slide << body
               @parent = body
@@ -340,6 +357,8 @@ module Rabbit
 
         def evaluate_inline_plugin(src)
           InlinePlugin.new(self).instance_eval(src, "(inline plugin)")
+        rescue ParseError
+          raise
         rescue
           @canvas.logger.warn($!)
           nil
@@ -347,12 +366,15 @@ module Rabbit
 
         def evaluate_block_plugin(src)
           BlockPlugin.new(self).instance_eval(src, "(block plugin)")
+        rescue ParseError
+          raise
         rescue
           @canvas.logger.warn($!)
           nil
         end
 
         class InlinePlugin
+          include GetText
           include Element
           include Parser::Ext::Inline
           include Parser::Ext::Entity
@@ -361,6 +383,11 @@ module Rabbit
             @private = Private.new(output)
           end
 
+          def image(source, props={})
+            raise ParseError,
+                  _("inline {{image(...)}} isn't supported.")
+          end
+
           def entity(entity, *rest)
             return nil unless TABLE.include?(entity)
 
@@ -434,12 +461,12 @@ module Rabbit
               body = @output.current_body
               if body["background-image"]
                 raise ParseError,
-                      _("multiple {{image, 'XXX.png', :align => :right}} " + \
+                      _("multiple {{image(..., :align => :right)}} " + \
                         "isn't supported.")
               end
               body["background-image"] = source
               props.each do |name, value|
-                name = name.to_s.gsub(/_/, '-')
+                name = name.to_s.gsub(/_/, "-")
                 value = value.to_s if name == "align"
                 body["background-image-#{name}"] = value
               end
