@@ -116,7 +116,7 @@ module Rabbit
           @area = Gtk::DrawingArea.new
           @area.can_focus = true
           set_map
-          set_expose_event
+          set_draw
           set_configure_event_after
         end
 
@@ -135,18 +135,27 @@ module Rabbit
           prepare_renderer(@drawable)
         end
 
-        def set_expose_event
-          @area.signal_connect("expose_event") do |widget, event|
-            init_renderer(@drawable)
-            result = exposed(widget, event)
-            finish_renderer
-            result
+        def set_draw
+          stop_events = false
+          if @area.class.signals.include?("draw")
+            @area.signal_connect("draw") do |widget, context|
+              init_context(context)
+              draw(widget, context)
+              finish_renderer
+              stop_events
+            end
+          else
+            @area.signal_connect("expose_event") do |widget, event|
+              init_renderer(@drawable)
+              draw(widget, @drawable.create_cairo_context)
+              finish_renderer
+              stop_events
+            end
           end
         end
 
-        def exposed(widget, event)
+        def draw(widget, context)
           draw_current_slide
-          true
         end
 
         def draw_current_slide
@@ -197,10 +206,10 @@ module Rabbit
         def grab
           Gtk.grab_add(@area)
           Gdk.pointer_grab(@area.window, false,
-                           Gdk::Event::BUTTON_PRESS_MASK |
-                           Gdk::Event::BUTTON_RELEASE_MASK |
-                           Gdk::Event::SCROLL_MASK |
-                           Gdk::Event::POINTER_MOTION_MASK,
+                           Gdk::EventMask::BUTTON_PRESS_MASK |
+                           Gdk::EventMask::BUTTON_RELEASE_MASK |
+                           Gdk::EventMask::SCROLL_MASK |
+                           Gdk::EventMask::POINTER_MOTION_MASK,
                            nil, nil,
                            Gdk::Event::CURRENT_TIME)
         end
