@@ -33,7 +33,7 @@ module Rabbit
           @magnifier_center_y = nil
 
           target_button = 3
-          target_event_type = Gdk::Event::BUTTON_PRESS
+          target_event_type = Gdk::EventType::BUTTON_PRESS
           target_info = [target_button, target_event_type]
 
           add_button_press_hook do |event|
