@@ -1,6 +1,4 @@
-require "rabbit/utils"
-
-Rabbit::Utils.require_safe "rabbit/renderer/engine/cairo"
+require "rabbit/renderer/engine/cairo"
 require "rabbit/renderer/pixmap/base"
 require "rabbit/renderer/pixmap/gl"
 
@@ -11,12 +9,6 @@ module Rabbit
         include Engine::Cairo
         include GL
         include Base
-
-        class << self
-          def priority
-            Engine::Cairo.priority
-          end
-        end
       end
     end
   end
