@@ -235,7 +235,7 @@ module Rabbit
       def rabbit(*arguments)
         unless Rabbit::Command::Rabbit.run(*arguments)
           message = "failed to run Rabbit"
-          message << ": #{arguments.join(', ')}" unless arguments.empty?
+          message << ": #{arguments.join(' ')}" unless arguments.empty?
           raise message
         end
       end
