@@ -18,17 +18,6 @@ include_theme("cozmixng-powered-by")
 @title_logo_image = "ruby-pink-polygon-logo.png"
 include_theme("title-logo")
 
-@slide_number_uninstall = true
-include_theme("slide-number")
-
-@image_slide_number_image = "mini-usa-taro.png"
-@image_slide_number_show_text = true
-include_theme("image-slide-number")
-if !print? and canvas.allotted_time
-  @image_timer_image = "mini-kame-taro.png"
-  include_theme("image-timer")
-end
-
 @icon_images = ["cozmixchu.png"]
 include_theme("icon")
 
