@@ -35,15 +35,15 @@ module Rabbit
 
     private
     def init_window
-      @video_window = Gtk::Window.new(Gtk::Window::POPUP)
+      @video_window = Gtk::Window.new(:popup)
       @video_window.modal = true
       @video_window.set_transient_for(window)
 
-      vbox = Gtk::VBox.new
+      vbox = Gtk::Box.new(:vertical)
       vbox.pack_start(@video)
       @video_window.add(vbox)
       @video_window.signal_connect('frame-event') do |widget, event|
-        if event.event_type == Gdk::Event::Type::BUTTON_PRESS
+        if event.event_type == Gdk::EventType::BUTTON_PRESS
           @video.toggle
         end
       end
