@@ -22,33 +22,12 @@ require "rabbit/source/memory"
 require "rabbit/parser/markdown"
 
 class RabbitParserMarkdownTest < Test::Unit::TestCase
+  include RabbitTestUtils::Fixture
+  include RabbitTestUtils::Parser
+
   private
   def parse(markdown)
-    canvas = []
-    def canvas.logger
-      Rabbit::Logger.default
-    end
-    source = Rabbit::Source::Memory.new("UTF-8", nil)
-    source.source = markdown
-    parser = Rabbit::Parser::Markdown.new(canvas, source)
-    parser.parse
-    canvas
-  end
-
-  def inspect_canvas(canvas)
-    canvas.collect do |page|
-      inspect_element(page)
-    end
-  end
-
-  def inspect_element(element)
-    name = element.class.name.split(/::/).last
-    if element.respond_to?(:elements)
-      children = element.elements.collect {|child| inspect_element(child)}
-    else
-      children = [element.text]
-    end
-    [name, *children]
+    super(Rabbit::Parser::Markdown, markdown)
   end
 
   class TitlePageTest < self
@@ -266,5 +245,72 @@ class RabbitParserMarkdownTest < Test::Unit::TestCase
                            MARKDOWN
       end
     end
+
+    class ListTest < self
+      class UnorderedListTest < self
+        class NesetedTest < self
+          def test_no_new_line_after_first_line
+            assert_equal([
+                           "Body", [
+                             "ItemList", [
+                               "ItemListItem", [
+                                 "Paragraph", ["Text", "First"],
+                               ], [
+                                 "ItemList", [
+                                   "ItemListItem", [
+                                     "Paragraph", ["Text", "Second"],
+                                   ],
+                                 ],
+                               ],
+                             ],
+                           ],
+                         ],
+                         parse(<<-MARKDOWN))
+* First
+  * Second
+                         MARKDOWN
+          end
+
+          def test_have_new_line_after_first_line
+            assert_equal([
+                           "Body", [
+                             "ItemList", [
+                               "ItemListItem", [
+                                 "Paragraph", ["Text", "First"],
+                               ], [
+                                 "ItemList", [
+                                   "ItemListItem", [
+                                     "Paragraph", ["Text", "Second"],
+                                   ],
+                                 ],
+                               ],
+                             ],
+                           ],
+                         ],
+                         parse(<<-MARKDOWN))
+* First
+
+  * Second
+                         MARKDOWN
+          end
+        end
+      end
+    end
+
+    class ImageTest < self
+      class InlineTest < self
+        include Rabbit::GetText
+
+        def test_unsupported
+          image_path = fixture_path("image/png/lavie.png")
+          message = _("multiple ![alt]{image} in a paragraph isn't supported.")
+          assert_raise(Rabbit::ParseError.new(message)) do
+            parse(<<-MARKDOWN)
+a ![](#{image_path})
+            MARKDOWN
+          end
+        end
+      end
+    end
   end
 end
