@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2012  Kouhei Sutou <kou@cozmixng.org>
+# Copyright (C) 2004-2015  Kouhei Sutou <kou@cozmixng.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,5 @@ require "test-unit"
 require "test/unit/notify"
 require "test/unit/rr"
 
-module RabbitTestUtils
-  private
-  def fixture_path(*components)
-    File.join(File.dirname(__FILE__), "fixtures", *components)
-  end
-end
+require "rabbit-test-utils/fixture"
+require "rabbit-test-utils/parser"
